package proxy.command;

import java.util.Locale;

import proxy.Proxy;
import proxy.network.ProxyHandler;

public class CommandHelp extends Command {
	public String getName() {
		return "help";
	}
	
	public String getHelp() {
		return "Displays proxy command help";
	}
	
	public String getArgs() {
		return "[command]";
	}
	
	private static String formatCommand(Command cmd, boolean prefix) {
		String args = cmd.getArgs();
		return (prefix ? "/vproxy " : "") + cmd.getName() + (args == null || args.isEmpty() ? "" : " " + args);
	}

	public void run(Proxy proxy, ProxyHandler player, String[] args) {
		if(args.length == 0) {
			for(Command cmd : proxy.getCommands().values()) {
				sendMessage(player, formatCommand(cmd, player != null));
			}
			return;
		}
		Command cmd = proxy.getCommands().get(args[0].toLowerCase(Locale.US));
		if(cmd == null)
			throw new RunException("Command '%s' not found", args[0]);
		sendMessage(player, formatCommand(cmd, player != null));
	}
	
	public Iterable<String> complete(Proxy proxy, ProxyHandler player, String[] args) {
		return args.length == 1 ? proxy.getCommands().keySet() : null;
	}
}
